@@ -41,7 +41,23 @@ utils::globalVariables(
     "ymin",
     "ymax",
     "pct",
-    "."
+    ".",
+    "alias",
+    "coef",
+    "coefficients",
+    "deviance",
+    "df.residual",
+    "makeHypothesis",
+    "model.frame",
+    "model.matrix",
+    "model.response",
+    "pchisq", 
+    "setNames", 
+    "terms", 
+    "vcov",
+    "model",
+    "error",
+    "bf"
   ),
   package = "CGPfunctions",
   add = FALSE
